Numina Pipeline Creation Guide — Numina 0.20.dev0 documentation

# Numina Pipeline Creation Guide

This guide is intended as an introductory overview of pipeline creation with Numina. For detailed reference documentation of the functions and classes contained in the package, see the Numina Reference.

Warning

This “Pipeline Creation Guide” is still a work in progress; some of the material is not organized, and several aspects of Numina are not covered in sufficient detail yet.

- Numina Pipeline Concepts
  - Instrument
  - Observing Modes
  - Recipes
  - Pipelines
  - Products, Requirements and Data Types
  - Format of the input files
    - Format of the Observation Result file
    - Format of the requirement file (version 1)
    - Format of the requirement file
- Numina Pipeline Example
  - Execution environment of the Recipes
  - Instrument Reduction Pipeline Example
    - Configuration File
    - Loader File
    - Create entry point
    - Recipes Creation
    - Specialized data products
- DRP Data Types
  - Create a new DataType
  - Construction of objects
  - Loading and Storage with the command line Recipe Loader